.. _tutorial:

********
Tutorial
********
ANDES can be used as a command-line tool or a library.
The command-line interface (CLI) comes handy to run studies.
As a library, it can be used interactively in the IPython shell or the Jupyter Notebook.
This chapter describes the most common usages.

Please see the CLI `cheatsheet`_ if you are looking for quick help.

.. _`cheatsheet`: https://cheatography.com/cuihantao/cheat-sheets/andes-for-power-system-simulation/

.. toctree::

   cli
   interactive
   cheatsheet
   makedocs
